@@ -1,6 +1,6 @@
-from . import variables  # noqa: package exported variables
+from . import variables, custom_types  # noqa: package exported variables
 from . import abstract, loaders  # noqa: package exported variables
 from .base_config import BaseConfig  # noqa: package exported variables
 from .dump_caster import DumpCaster  # noqa: package exported variables
 
-__version__ = "2.0.8"
+__version__ = "2.1.0"
